!(function () {
    var Widget = BI.inherit(BI.Widget, {

        _store: function () {
            return BI.Models.getModel("dec.model.plugin.public_link");
        },

        watch: {
            currentPageItems: function () {
                this.populate(this.model.currentPageItems);
            },

            totalCount: function (count) {
                this.pager.setCount(count);
            },

            pages: function (pages) {
                this.pager.setAllPages(pages);
            },

            page: function (v) {
                this.pager.setPage(v);
            },
        },

        mounted: function () {
            this.store.getPublicLinkDashboards();
        },

        render: function () {
            var self = this;

            return {
                type: "bi.absolute",
                items: [
                    {
                        el: this._createFilter(),
                        top: 10, left: 10, right: 10,
                    }, {
                        el: {
                            type: "bi.vtape",
                            cls: "bi-card",
                            hgap: 15,
                            items: [
                                {
                                    el: this._createHeader(),
                                    height: 36,
                                }, {
                                    el: {
                                        type: "bi.button_group",
                                        ref: function (_ref) {
                                            self.list = _ref;
                                        },
                                        layouts: [
                                            {
                                                type: "bi.vertical",
                                            },
                                        ],
                                        items: [],
                                    },
                                },
                            ],
                        },
                        top: 90, left: 10, right: 10, bottom: 40,
                    }, {
                        el: this._createPager(),
                        height: 30,
                        bottom: 10, left: 10, right: 10,
                    },
                ],
            };
        },

        _createFilter: function () {
            var self = this;

            var userSelector = {
                type: "bi.value_chooser_combo",
                ref: function (_ref) {
                    self.user = _ref;
                },
                itemsCreator: function (op, callback) {
                    self.store.getPublicLinkDashboardUsers(callback);
                },
                listeners: [
                    {
                        eventName: "EVENT_CONFIRM",
                        action: function () {
                            self.store.updateUsersFilter(this.getAllValue());
                        },
                    },
                ],
            };

            var time = {
                type: "bi.date_interval",
                ref: function (_ref) {
                    self.time = _ref;
                },
                width: 320,
                listeners: [
                    {
                        eventName: "EVENT_CHANGE",
                        action: function () {
                            self.store.updateTimeIntervalFilter(this.getValue());
                        },
                    },
                ],
            };


            var trigger = {
                type: "bi.select_text_trigger",
                cls: "text-value-trigger",
                items: BI.Constants.getConstant("dec.constant.plugin.public_link.export_status"),
                height: 22,
                value: "",
                text: BI.i18nText("BI-Basic_Please_Select"),
            };

            var status = {
                type: "bi.combo",
                ref: function (_ref) {
                    self.statusCombo = _ref;
                },
                cls: "bi-border bi-focus-shadow bi-border-radius",
                adjustLength: 2,
                el: trigger,
                width: 150,
                innerVGap: 5,
                popup: {
                    el: {
                        type: "bi.button_group",
                        ref: function (_ref) {
                            self.status = _ref;
                        },
                        layouts: [
                            {
                                type: "bi.vertical",
                                hgap: 10,
                            },
                        ],
                        items: BI.createItems(BI.Constants.getConstant("dec.constant.plugin.public_link.export_status"), {
                            type: "bi.single_select_radio_item",
                            cls: "bi-list-item-none",
                        }),
                        listeners: [{
                            eventName: "EVENT_CHANGE",
                            action: function (v) {
                                self.store.updateStatusFilter(v);
                                self.statusCombo.hideView();
                            },
                        }],
                    },
                    maxHeight: 240,
                    minHeight: 25,
                },
            };

            return {
                type: "bi.vertical",
                vgap: 10,
                hgap: 15,
                cls: "bi-card",
                height: 80,
                items: [
                    {
                        el: {
                            type: "bi.vertical_adapt",
                            rgap: 30,
                            items: [
                                {
                                    el: {
                                        type: "bi.vertical_adapt",
                                        items: [
                                            {
                                                type: "bi.label",
                                                text: BI.i18nText("BI-Plugin_Public_Link_Export_Create_User"),
                                                textAlign: "left",
                                                rgap: 10,
                                            }, {
                                                el: userSelector,
                                            },
                                        ],
                                    },
                                }, {
                                    el: {
                                        type: "bi.vertical_adapt",
                                        items: [
                                            {
                                                type: "bi.label",
                                                text: BI.i18nText("Dec-Latest_Revision_Date"),
                                                textAlign: "left",
                                                rgap: 10,
                                            }, {
                                                el: time,
                                            },
                                        ],
                                    },
                                }, {
                                    el: {
                                        type: "bi.vertical_adapt",
                                        items: [
                                            {
                                                type: "bi.label",
                                                text: BI.i18nText("Dec-Basic_Export"),
                                                textAlign: "left",
                                                rgap: 10,
                                            }, {
                                                el: status,
                                            },
                                        ],
                                    },
                                },
                            ],
                        },
                    }, {
                        type: "bi.vertical_adapt",
                        items: [
                            {
                                type: "bi.label",
                                text: BI.i18nText("BI-Platform_Dashboard"),
                                textAlign: "left",
                                rgap: 16,
                            }, {
                                el: {
                                    type: "bi.text_editor",
                                    ref: function (_ref) {
                                        self.searcher = _ref;
                                    },
                                    width: 200,
                                    hgap: 2,
                                    allowBlank: true,
                                    watermark: BI.i18nText("Dec-Please_Input"),
                                    listeners: [
                                        {
                                            eventName: "EVENT_CHANGE",
                                            action: function () {
                                                self.store.updateKeywordFilter(this.getValue());
                                            },
                                        },
                                    ],
                                },
                            },
                            {
                                el: {
                                    type: "bi.button",
                                    height: 24,
                                    width: 100,
                                    text: BI.i18nText("Dec-Basic_Query"),
                                    handler: function () {
                                        self.store.getPublicLinkDashboards();
                                    },
                                },
                                lgap: 30
                            }, {
                                el: {
                                    type: "bi.button",
                                    height: 24,
                                    width: 100,
                                    text: BI.i18nText("Dec-BI_Template_Filter_Reset"),
                                    handler: function () {
                                        self.store.resetFilter();
                                        self._resetFilter();
                                    },
                                },
                                lgap: 15
                            }
                        ],
                    },
                ],
            };
        },

        _createHeader: function () {
            var self = this;

            return {
                type: "bi.htape",
                cls: "dec-page-table-header",
                height: 36,
                items: [
                    {
                        type: "bi.htape",
                        items: [
                            {
                                el: {
                                    type: "bi.label",
                                    textAlign: "left",
                                    text: BI.i18nText("BI-Plugin_Public_Link_Export_Create_User"),
                                    lgap: 10,
                                },
                                width: 0.2,
                            }, {
                                el: {
                                    type: "bi.label",
                                    textAlign: "left",
                                    text: BI.i18nText("BI-Platform_Dashboard"),
                                    lgap: 10,
                                },
                                width: 0.6,
                            }, {
                                el: {
                                    type: "bi.label",
                                    textAlign: "left",
                                    text: BI.i18nText("Dec-Latest_Revision_Date"),
                                    lgap: 10,
                                },
                                width: 0.2,
                            },
                        ],
                    }, {
                        el: {
                            type: "bi.label",
                            text: BI.i18nText("Dec-Basic_Export"),
                        },
                        width: 60,
                    },
                ],
            };
        },

        _createItems: function (items) {
            //  任务名,创建者,上次执行时间
            var self = this;

            return BI.map(items, function (index, item) {
                return {
                    type: "bi.htape",
                    key: item.id,
                    height: 30,
                    cls: (index % 2 !== 0) ? "dec-page-table-row row-even" : "dec-page-table-row",
                    items: [
                        {
                            type: "bi.htape",
                            items: [
                                {
                                    el: {
                                        type: "bi.label",
                                        textAlign: "left",
                                        text: BI.isNull(item.createBy) ? BI.i18nText('BI-Plugin_Public_Unknown_User') : item.createBy,
                                        lgap: 10,
                                    },
                                    width: 0.2,
                                }, {
                                    el: {
                                        type: "bi.label",
                                        textAlign: "left",
                                        text: item.name,
                                        lgap: 10,
                                    },
                                    width: 0.6,
                                }, {
                                    el: {
                                        type: "bi.label",
                                        textAlign: "left",
                                        text: BI.getDate(item.modifyTime).print("%Y-%X-%d %H:%M:%S"),
                                        lgap: 10,
                                    },
                                    width: 0.2,
                                },
                            ],
                        }, {
                            el: {
                                type: "bi.icon_change_button",
                                iconCls: item.exportable ? "auth-on-font" : "auth-off-font",
                                selected: !!item.exportable,
                                listeners: [
                                    {
                                        eventName: BI.IconButton.EVENT_CHANGE,
                                        action: function () {
                                            var selected = this.isSelected();
                                            self.store.updatePublicLinDashboardExport(item.id, selected);
                                            this.setIcon(selected ? "auth-on-font" : "auth-off-font");
                                        },
                                    },
                                ],
                            },
                            width: 60,
                        },
                    ],
                };
            });
        },

        _createPager: function () {
            var self = this;

            return {
                type: "bi.right_vertical_adapt",
                cls: "bi-card",
                height: 30,
                rgap: 20,
                items: [
                    {
                        type: "dec.pager",
                        count: this.model.totalCount,
                        pages: this.model.pages,
                        ref: function (_ref) {
                            self.pager = _ref;
                        },
                        listeners: [{
                            eventName: "EVENT_CHANGE",
                            action: function () {
                                self.store.setPage(this.getCurrentPage());
                            },
                        }],
                    },
                ],
            };
        },

        _resetFilter: function () {
            this.user.setValue();
            this.statusCombo.setValue();
            this.time.setValue();
            this.searcher.setValue("");
        },

        populate: function (items) {
            this.list.populate(this._createItems(items));
        },
    });

    BI.shortcut("dec.plugin.public_link", Widget);
}());
