!(function () {
    var PER_PAGE = 30;

    var Model = BI.inherit(Fix.Model, {

        state: function () {
            return {
                dashboards: [],
                filter: {
                    users: [],
                    keyword: "",
                    start: null,
                    end: null,
                    status: [],
                },
                page: 1,
            };
        },

        computed: {
            totalCount: function () {
                return this.model.dashboards.length;
            },
            pages: function () {
                return BI.max([Math.ceil(this.model.totalCount / PER_PAGE), 1]);
            },
            currentPageItems: function () {
                var dashboards = this.model.dashboards;
                var page = this.model.page;

                return dashboards.slice((page - 1) * PER_PAGE, page * PER_PAGE);
            },
        },

        watch: {},

        actions: {

            getPublicLinkDashboards: function () {
                var self = this;
                Dec.Utils.plugin.getPublicLinkDashboards(this.model.filter, function (res) {
                    self.model.dashboards = self._sortDashboards(res.data);
                    self.model.page = 1;
                });
            },

            getPublicLinkDashboardUsers: function (cb) {
                Dec.Utils.plugin.getPublicLinkDashboardUsers(function (res) {
                    BI.each(res.data, function (index, item) {
                        item.value = item.id || item.userId;
                        item.text = BI.isNull(item.userName) ? BI.i18nText('BI-Plugin_Public_Unknown_User') : item.userName;
                    });
                    cb(res.data);
                });
            },

            resetFilter: function () {
                this.model.filter = {
                    users: [],
                    keyword: "",
                    start: null,
                    end: null,
                    status: [],
                };
                this.getPublicLinkDashboards();
            },

            updateKeywordFilter: function (value) {
                this.model.filter.keyword = value;
            },

            updateTimeIntervalFilter: function (timeInterval) {
                if (!BI.isNull(timeInterval.start)) {
                    this.model.filter.start = BI.getTime(BI.parseDateTime(Dec.Utils.getDynamicDateValue(timeInterval.start) + DecCst.DATA_INTERVAL_START_TIME, "%Y-%X-%d %H:%M:%S"));
                } else {
                    this.model.filter.start = null;
                }
                if (!BI.isNull(timeInterval.end)) {
                    this.model.filter.end = BI.getTime(BI.parseDateTime(Dec.Utils.getDynamicDateValue(timeInterval.end) + DecCst.DATA_INTERVAL_END_TIME, "%Y-%X-%d %H:%M:%S"));
                } else {
                    this.model.filter.end = null;
                }
            },

            updateUsersFilter: function (value) {
                this.model.filter.users = value;
            },

            updateStatusFilter: function (value) {
                this.model.filter.status = [value];
            },

            setPage: function (v) {
                this.model.page = v;
            },

            updatePublicLinDashboardExport: function (id, selected) {
                var self = this;
                var exportable = selected ? 1 : 0;
                var index = BI.findIndex(this.model.dashboards, function (index, item) {
                    return item.id === id;
                });
                var dashboard = BI.extend({}, this.model.dashboards[index], {
                    exportable: exportable,
                });

                Dec.Utils.plugin.updatePublicLinDashboardExport({
                    id: id,
                    exportable: exportable,
                }, function (res) {
                    self.model.dashboards[index].exportable = exportable;
                });
            },
        },

        _sortDashboards: function (items) {
            return BI.sortBy(items, "modifyTime").reverse();
        },
    });
    BI.model("dec.model.plugin.public_link", Model);
}());
